from typing import Any, ClassVar, Optional

from typing import overload
import datetime
import depthai
import os

class AprilTag(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.AprilTagConfig
        inputConfigSync: bool
        numThreads: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getNumThreads(self) -> int: ...
    def getWaitForConfigInput(self) -> bool: ...
    def runOnHost(self) -> bool: ...
    def setNumThreads(self, numThreads: int) -> None: ...
    def setRunOnHost(self, arg0: bool) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def initialConfig(self) -> depthai.AprilTagConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def passthroughInputImage(self) -> depthai.Node.Output: ...

class BenchmarkIn(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def logReportsAsWarnings(self, logReportsAsWarnings: bool) -> None: ...
    def measureIndividualLatencies(self, attachLatencies: bool) -> None: ...
    def sendReportEveryNMessages(self, num: int) -> None: ...
    def setRunOnHost(self, runOnHost: bool) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def passthrough(self) -> depthai.Node.Output: ...
    @property
    def report(self) -> depthai.Node.Output: ...

class BenchmarkOut(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def setFps(self, fps: float) -> None: ...
    def setNumMessagesToSend(self, num: int) -> None: ...
    def setRunOnHost(self, runOnHost: bool) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class Camera(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def build(self, boardSocket: depthai.CameraBoardSocket = ..., sensorResolution: Optional[tuple[int,int]] = ..., sensorFps: Optional[float] = ...) -> Camera: ...
    @overload
    def build(self, boardSocket: depthai.CameraBoardSocket, replayNode: ReplayVideo) -> Camera: ...
    @overload
    def build(self, replayNode: ReplayVideo) -> Camera: ...
    def getBoardSocket(self) -> depthai.CameraBoardSocket: ...
    def requestFullResolutionOutput(self, type: Optional[depthai.ImgFrame.Type] = ..., fps: Optional[float] = ..., useHighestResolution: bool = ...) -> depthai.Node.Output: ...
    @overload
    def requestOutput(self, size: tuple[int,int], type: Optional[depthai.ImgFrame.Type] = ..., resizeMode: depthai.ImgResizeMode = ..., fps: Optional[float] = ..., enableUndistortion: Optional[bool] = ...) -> depthai.Node.Output: ...
    @overload
    def requestOutput(self, capability: depthai.Capability, onHost: bool) -> depthai.Node.Output: ...
    def setMockIsp(self, mockIsp: ReplayVideo) -> Camera: ...
    @property
    def initialControl(self) -> depthai.CameraControl: ...
    @property
    def inputControl(self) -> depthai.Node.Input: ...
    @property
    def mockIsp(self) -> depthai.Node.Input: ...
    @property
    def raw(self) -> depthai.Node.Output: ...

class ColorCamera(depthai.DeviceNode):
    class Properties:
        class ColorOrder:
            __members__: ClassVar[dict] = ...  # read-only
            BGR: ClassVar[depthai.ColorCameraProperties.ColorOrder] = ...
            RGB: ClassVar[depthai.ColorCameraProperties.ColorOrder] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class SensorResolution:
            __members__: ClassVar[dict] = ...  # read-only
            THE_1080_P: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_1200_P: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_1280X962: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_12_MP: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_1352X1012: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_13_MP: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_1440X1080: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_2000X1500: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_2024X1520: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_2028X1520: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_2104X1560: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_240X180: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_4000X3000: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_48_MP: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_4_K: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_5312X6000: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_5_MP: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_720_P: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            THE_800_P: ClassVar[depthai.ColorCameraProperties.SensorResolution] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class WarpMeshSource:
            __members__: ClassVar[dict] = ...  # read-only
            AUTO: ClassVar[depthai.ColorCameraProperties.WarpMeshSource] = ...
            CALIBRATION: ClassVar[depthai.ColorCameraProperties.WarpMeshSource] = ...
            NONE: ClassVar[depthai.ColorCameraProperties.WarpMeshSource] = ...
            URI: ClassVar[depthai.ColorCameraProperties.WarpMeshSource] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        boardSocket: depthai.CameraBoardSocket
        calibAlpha: float
        eventFilter: list[depthai.FrameEvent]
        fps: float
        imageOrientation: depthai.CameraImageOrientation
        initialControl: depthai.CameraControl
        isp3aFps: int
        ispScale: Any
        numFramesPoolIsp: int
        numFramesPoolPreview: int
        numFramesPoolRaw: int
        numFramesPoolStill: int
        numFramesPoolVideo: int
        previewHeight: int
        previewKeepAspectRatio: bool
        previewWidth: int
        resolution: depthai.ColorCameraProperties.SensorResolution
        sensorCropX: float
        sensorCropY: float
        stillHeight: int
        stillWidth: int
        videoHeight: int
        videoWidth: int
        warpMeshHeight: int
        warpMeshSource: depthai.ColorCameraProperties.WarpMeshSource
        warpMeshStepHeight: int
        warpMeshStepWidth: int
        warpMeshUri: str
        warpMeshWidth: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self) -> None: ...
    def getBoardSocket(self) -> depthai.CameraBoardSocket: ...
    def getCalibrationAlpha(self) -> float: ...
    def getCamId(self) -> int: ...
    def getCamera(self) -> str: ...
    def getColorOrder(self) -> depthai.ColorCameraProperties.ColorOrder: ...
    def getFp16(self) -> bool: ...
    def getFps(self) -> float: ...
    def getFrameEventFilter(self) -> list[depthai.FrameEvent]: ...
    def getImageOrientation(self) -> depthai.CameraImageOrientation: ...
    def getInterleaved(self) -> bool: ...
    def getIspHeight(self) -> int: ...
    def getIspNumFramesPool(self) -> int: ...
    def getIspSize(self) -> tuple[int,int]: ...
    def getIspWidth(self) -> int: ...
    def getMeshSize(self) -> tuple[int,int]: ...
    def getMeshSource(self) -> depthai.ColorCameraProperties.WarpMeshSource: ...
    def getMeshStep(self) -> tuple[int,int]: ...
    def getPreviewHeight(self) -> int: ...
    def getPreviewKeepAspectRatio(self) -> bool: ...
    def getPreviewNumFramesPool(self) -> int: ...
    def getPreviewSize(self) -> tuple[int,int]: ...
    def getPreviewWidth(self) -> int: ...
    def getRawNumFramesPool(self) -> int: ...
    def getResolution(self) -> depthai.ColorCameraProperties.SensorResolution: ...
    def getResolutionHeight(self) -> int: ...
    def getResolutionSize(self) -> tuple[int,int]: ...
    def getResolutionWidth(self) -> int: ...
    def getSensorCrop(self) -> tuple[float,float]: ...
    def getSensorCropX(self) -> float: ...
    def getSensorCropY(self) -> float: ...
    def getStillHeight(self) -> int: ...
    def getStillNumFramesPool(self) -> int: ...
    def getStillSize(self) -> tuple[int,int]: ...
    def getStillWidth(self) -> int: ...
    def getVideoHeight(self) -> int: ...
    def getVideoNumFramesPool(self) -> int: ...
    def getVideoSize(self) -> tuple[int,int]: ...
    def getVideoWidth(self) -> int: ...
    def getWaitForConfigInput(self) -> bool: ...
    def loadMeshData(self, warpMesh, std) -> None: ...
    def sensorCenterCrop(self) -> None: ...
    def setBoardSocket(self, boardSocket: depthai.CameraBoardSocket) -> None: ...
    def setCalibrationAlpha(self, alpha: float) -> None: ...
    def setCamId(self, arg0: int) -> None: ...
    def setCamera(self, name: str) -> None: ...
    def setColorOrder(self, colorOrder: depthai.ColorCameraProperties.ColorOrder) -> None: ...
    def setFp16(self, fp16: bool) -> None: ...
    def setFps(self, fps: float) -> None: ...
    def setFrameEventFilter(self, events: list[depthai.FrameEvent]) -> None: ...
    def setImageOrientation(self, imageOrientation: depthai.CameraImageOrientation) -> None: ...
    def setInterleaved(self, interleaved: bool) -> None: ...
    def setIsp3aFps(self, arg0: int) -> None: ...
    def setIspNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setIspScale(self, numerator: int, denominator: int) -> None: ...
    @overload
    def setIspScale(self, scale: tuple[int,int]) -> None: ...
    @overload
    def setIspScale(self, horizNum: int, horizDenom: int, vertNum: int, vertDenom: int) -> None: ...
    @overload
    def setIspScale(self, horizScale: tuple[int,int], vertScale: tuple[int,int]) -> None: ...
    def setMeshSize(self, width: int, height: int) -> None: ...
    def setMeshSource(self, source: depthai.ColorCameraProperties.WarpMeshSource) -> None: ...
    def setMeshStep(self, width: int, height: int) -> None: ...
    def setNumFramesPool(self, raw: int, isp: int, preview: int, video: int, still: int) -> None: ...
    def setPreviewKeepAspectRatio(self, keep: bool) -> None: ...
    def setPreviewNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setPreviewSize(self, width: int, height: int) -> None: ...
    @overload
    def setPreviewSize(self, size: tuple[int,int]) -> None: ...
    def setRawNumFramesPool(self, arg0: int) -> None: ...
    def setRawOutputPacked(self, packed: bool) -> None: ...
    def setResolution(self, resolution: depthai.ColorCameraProperties.SensorResolution) -> None: ...
    def setSensorCrop(self, x: float, y: float) -> None: ...
    def setStillNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setStillSize(self, width: int, height: int) -> None: ...
    @overload
    def setStillSize(self, size: tuple[int,int]) -> None: ...
    def setVideoNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setVideoSize(self, width: int, height: int) -> None: ...
    @overload
    def setVideoSize(self, size: tuple[int,int]) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def frameEvent(self) -> depthai.Node.Output: ...
    @property
    def initialControl(self) -> depthai.CameraControl: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputControl(self) -> depthai.Node.Input: ...
    @property
    def isp(self) -> depthai.Node.Output: ...
    @property
    def preview(self) -> depthai.Node.Output: ...
    @property
    def raw(self) -> depthai.Node.Output: ...
    @property
    def still(self) -> depthai.Node.Output: ...
    @property
    def video(self) -> depthai.Node.Output: ...

class DetectionNetwork(depthai.DeviceNodeGroup):
    def __init__(self, input: depthai.Node.Output, nnArchive: depthai.NNArchive, confidenceThreshold: float = ...) -> None: ...
    @overload
    def build(self, input: depthai.Node.Output, nnArchive: depthai.NNArchive, confidenceThreshold: float = ...) -> DetectionNetwork: ...
    @overload
    def build(self, input: Camera, model: depthai.NNModelDescription, fps: Optional[float] = ...) -> DetectionNetwork: ...
    @overload
    def build(self, input: Camera, model: str, fps: Optional[float] = ...) -> DetectionNetwork: ...
    @overload
    def build(self, input: Camera, nnArchive: depthai.NNArchive, fps: Optional[float] = ...) -> DetectionNetwork: ...
    @overload
    def build(self, input: ReplayVideo, model: depthai.NNModelDescription, fps: Optional[float] = ...) -> DetectionNetwork: ...
    @overload
    def build(self, input: ReplayVideo, nnArchive: depthai.NNArchive, fps: Optional[float] = ...) -> DetectionNetwork: ...
    def getClasses(self) -> Optional[list[str]]: ...
    def getConfidenceThreshold(self) -> float: ...
    def getNumInferenceThreads(self) -> int: ...
    def setBackend(self, setBackend: str) -> None: ...
    def setBackendProperties(self, setBackendProperties: dict[str,str]) -> None: ...
    @overload
    def setBlob(self, blob: depthai.OpenVINO.Blob) -> None: ...
    @overload
    def setBlob(self, path: Path) -> None: ...
    def setBlobPath(self, path: Path) -> None: ...
    def setConfidenceThreshold(self, thresh: float) -> None: ...
    def setFromModelZoo(self, description: depthai.NNModelDescription, useCached: bool = ...) -> None: ...
    def setModelPath(self, modelPath: Path) -> None: ...
    @overload
    def setNNArchive(self, archive: depthai.NNArchive) -> None: ...
    @overload
    def setNNArchive(self, archive: depthai.NNArchive, numShaves: int) -> None: ...
    def setNumInferenceThreads(self, numThreads: int) -> None: ...
    def setNumNCEPerInferenceThread(self, numNCEPerThread: int) -> None: ...
    def setNumPoolFrames(self, numFrames: int) -> None: ...
    def setNumShavesPerInferenceThread(self, numShavesPerInferenceThread: int) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def outNetwork(self) -> depthai.Node.Output: ...
    @property
    def passthrough(self) -> depthai.Node.Output: ...

class DetectionParser(depthai.DeviceNode):
    class Properties:
        parser: depthai.DetectionParserOptions
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def build(self, arg0: depthai.Node.Output, arg1: depthai.NNArchive) -> DetectionParser: ...
    def getAnchorMasks(self) -> dict[str,list[int]]: ...
    def getAnchors(self) -> list[float]: ...
    def getConfidenceThreshold(self) -> float: ...
    def getCoordinateSize(self) -> int: ...
    def getIouThreshold(self) -> float: ...
    def getNNFamily(self) -> depthai.DetectionNetworkType: ...
    def getNumClasses(self) -> int: ...
    def getNumFramesPool(self) -> int: ...
    def setAnchorMasks(self, anchorMasks: dict[str,list[int]]) -> None: ...
    @overload
    def setAnchors(self, anchors: list[list[list[float]]]) -> None: ...
    @overload
    def setAnchors(self, anchors: list[float]) -> None: ...
    @overload
    def setBlob(self, blob: depthai.OpenVINO.Blob) -> None: ...
    @overload
    def setBlob(self, path: Path) -> None: ...
    def setBlobPath(self, path: Path) -> None: ...
    def setConfidenceThreshold(self, thresh: float) -> None: ...
    def setCoordinateSize(self, coordinates: int) -> None: ...
    @overload
    def setInputImageSize(self, width: int, height: int) -> None: ...
    @overload
    def setInputImageSize(self, size: tuple[int,int]) -> None: ...
    def setIouThreshold(self, thresh: float) -> None: ...
    def setNNArchive(self, nnArchive: depthai.NNArchive) -> None: ...
    def setNNFamily(self, type: depthai.DetectionNetworkType) -> None: ...
    def setNumClasses(self, numClasses: int) -> None: ...
    def setNumFramesPool(self, numFramesPool: int) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class EdgeDetector(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.EdgeDetectorConfig
        numFramesPool: int
        outputFrameSize: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getWaitForConfigInput(self) -> bool: ...
    def setMaxOutputFrameSize(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def initialConfig(self) -> depthai.EdgeDetectorConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def outputImage(self) -> depthai.Node.Output: ...

class FeatureTracker(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.FeatureTrackerConfig
        numMemorySlices: int
        numShaves: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getWaitForConfigInput(self) -> bool: ...
    def setHardwareResources(self, numShaves: int, numMemorySlices: int) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def initialConfig(self) -> depthai.FeatureTrackerConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def outputFeatures(self) -> depthai.Node.Output: ...
    @property
    def passthroughInputImage(self) -> depthai.Node.Output: ...

class HostNode(ThreadedHostNode):
    createSubnode: ClassVar[function] = ...
    __init_subclass__: ClassVar[method] = ...
    def __init__(self) -> None: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def processGroup(self, arg0: depthai.MessageGroup) -> depthai.Buffer: ...
    def runSyncingOnDevice(self) -> None: ...
    def runSyncingOnHost(self) -> None: ...
    def sendProcessingToPipeline(self, arg0: bool) -> None: ...
    @property
    def inputs(self) -> depthai.Node.InputMap: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class IMU(depthai.DeviceNode):
    class Properties:
        batchReportThreshold: int
        enableFirmwareUpdate: Optional[bool]
        imuSensors: list[depthai.IMUSensorConfig]
        maxBatchReports: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def enableFirmwareUpdate(self, arg0: bool) -> None: ...
    @overload
    def enableIMUSensor(self, sensorConfig: depthai.IMUSensorConfig) -> None: ...
    @overload
    def enableIMUSensor(self, sensorConfigs: list[depthai.IMUSensorConfig]) -> None: ...
    @overload
    def enableIMUSensor(self, sensor: depthai.IMUSensor, reportRate: int) -> None: ...
    @overload
    def enableIMUSensor(self, sensors: list[depthai.IMUSensor], reportRate: int) -> None: ...
    def getBatchReportThreshold(self) -> int: ...
    def getMaxBatchReports(self) -> int: ...
    def setBatchReportThreshold(self, batchReportThreshold: int) -> None: ...
    def setMaxBatchReports(self, maxBatchReports: int) -> None: ...
    @property
    def mockIn(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class ImageAlign(depthai.DeviceNode):
    class Properties:
        alignHeight: int
        alignWidth: int
        initialConfig: depthai.ImageAlignConfig
        interpolation: depthai.Interpolation
        numFramesPool: int
        numShaves: int
        outKeepAspectRatio: bool
        warpHwIds: list[int]
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setInterpolation(self, interp: depthai.Interpolation) -> ImageAlign: ...
    def setNumFramesPool(self, numFramesPool: int) -> ImageAlign: ...
    def setNumShaves(self, numShaves: int) -> ImageAlign: ...
    def setOutKeepAspectRatio(self, keep: bool) -> ImageAlign: ...
    def setOutputSize(self, alignWidth: int, alignHeight: int) -> ImageAlign: ...
    @property
    def initialConfig(self) -> depthai.ImageAlignConfig: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def inputAlignTo(self) -> depthai.Node.Input: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def outputAligned(self) -> depthai.Node.Output: ...
    @property
    def passthroughInput(self) -> depthai.Node.Output: ...

class ImageManip(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getWaitForConfigInput(self) -> bool: ...
    def setCenterCrop(self, arg0: float, arg1: float) -> None: ...
    def setCropRect(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    def setFrameType(self, arg0: depthai.ImgFrame.Type) -> None: ...
    def setHorizontalFlip(self, arg0: bool) -> None: ...
    def setKeepAspectRatio(self, arg0: bool) -> None: ...
    def setMaxOutputFrameSize(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setResize(self, arg0: int, arg1: int) -> None: ...
    def setResizeThumbnail(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int) -> None: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @overload
    def setWarpMesh(self, arg0: depthai.VectorPoint2f, arg1: int, arg2: int) -> None: ...
    @overload
    def setWarpMesh(self, arg0: list[tuple[float,float]], arg1: int, arg2: int) -> None: ...
    @property
    def initialConfig(self) -> depthai.ImageManipConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class ImageManipV2(depthai.DeviceNode):
    class Backend:
        __members__: ClassVar[dict] = ...  # read-only
        CPU: ClassVar[ImageManipV2.Backend] = ...
        HW: ClassVar[ImageManipV2.Backend] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class PerformanceMode:
        __members__: ClassVar[dict] = ...  # read-only
        BALANCED: ClassVar[ImageManipV2.PerformanceMode] = ...
        LOW_POWER: ClassVar[ImageManipV2.PerformanceMode] = ...
        PERFORMANCE: ClassVar[ImageManipV2.PerformanceMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setBackend(self, arg0: ImageManipV2.Backend) -> ImageManipV2: ...
    def setMaxOutputFrameSize(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setPerformanceMode(self, arg0: ImageManipV2.PerformanceMode) -> ImageManipV2: ...
    def setRunOnHost(self, arg0: bool) -> ImageManipV2: ...
    @property
    def initialConfig(self) -> depthai.ImageManipConfigV2: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class MessageDemux(depthai.DeviceNode):
    class Properties:
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def outputs(self) -> depthai.Node.OutputMap: ...

class MobileNetDetectionNetwork(DetectionNetwork):
    def __init__(self, *args, **kwargs) -> None: ...

class MobileNetSpatialDetectionNetwork(SpatialDetectionNetwork):
    def __init__(self, *args, **kwargs) -> None: ...

class MonoCamera(depthai.DeviceNode):
    class Properties:
        class SensorResolution:
            __members__: ClassVar[dict] = ...  # read-only
            THE_1200_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_4000X3000: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_400_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_4224X3136: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_480_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_720_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            THE_800_P: ClassVar[depthai.MonoCameraProperties.SensorResolution] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        boardSocket: depthai.CameraBoardSocket
        eventFilter: list[depthai.FrameEvent]
        fps: float
        initialControl: depthai.CameraControl
        isp3aFps: int
        numFramesPool: int
        numFramesPoolRaw: int
        resolution: depthai.MonoCameraProperties.SensorResolution
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getBoardSocket(self) -> depthai.CameraBoardSocket: ...
    def getCamId(self) -> int: ...
    def getCamera(self) -> str: ...
    def getFps(self) -> float: ...
    def getFrameEventFilter(self) -> list[depthai.FrameEvent]: ...
    def getImageOrientation(self) -> depthai.CameraImageOrientation: ...
    def getNumFramesPool(self) -> int: ...
    def getRawNumFramesPool(self) -> int: ...
    def getResolution(self) -> depthai.MonoCameraProperties.SensorResolution: ...
    def getResolutionHeight(self) -> int: ...
    def getResolutionSize(self) -> tuple[int,int]: ...
    def getResolutionWidth(self) -> int: ...
    def setBoardSocket(self, boardSocket: depthai.CameraBoardSocket) -> None: ...
    def setCamId(self, arg0: int) -> None: ...
    def setCamera(self, name: str) -> None: ...
    def setFps(self, fps: float) -> None: ...
    def setFrameEventFilter(self, events: list[depthai.FrameEvent]) -> None: ...
    def setImageOrientation(self, imageOrientation: depthai.CameraImageOrientation) -> None: ...
    def setIsp3aFps(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setRawNumFramesPool(self, arg0: int) -> None: ...
    def setRawOutputPacked(self, packed: bool) -> None: ...
    def setResolution(self, resolution: depthai.MonoCameraProperties.SensorResolution) -> None: ...
    @property
    def frameEvent(self) -> depthai.Node.Output: ...
    @property
    def initialControl(self) -> depthai.CameraControl: ...
    @property
    def inputControl(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def raw(self) -> depthai.Node.Output: ...

class NeuralNetwork(depthai.DeviceNode):
    class Properties:
        blobSize: Optional[int]
        blobUri: str
        numFrames: int
        numNCEPerThread: int
        numThreads: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def build(self, input: depthai.Node.Output, nnArchive: depthai.NNArchive) -> NeuralNetwork: ...
    @overload
    def build(self, input: Camera, modelDesc: depthai.NNModelDescription, fps: Optional[float] = ...) -> NeuralNetwork: ...
    @overload
    def build(self, input: Camera, model: depthai.NNArchive, fps: Optional[float] = ...) -> NeuralNetwork: ...
    @overload
    def build(self, input: Camera, model: str, fps: Optional[float] = ...) -> NeuralNetwork: ...
    @overload
    def build(self, input: ReplayVideo, model: depthai.NNArchive, fps: Optional[float] = ...) -> NeuralNetwork: ...
    @overload
    def build(self, input: ReplayVideo, nnArchive: depthai.NNArchive, fps: Optional[float] = ...) -> NeuralNetwork: ...
    def getNumInferenceThreads(self) -> int: ...
    def setBackend(self, setBackend: str) -> None: ...
    def setBackendProperties(self, setBackendProperties: dict[str,str]) -> None: ...
    @overload
    def setBlob(self, blob: depthai.OpenVINO.Blob) -> None: ...
    @overload
    def setBlob(self, path: Path) -> None: ...
    def setBlobPath(self, path: Path) -> None: ...
    def setFromModelZoo(self, description: depthai.NNModelDescription, useCached: bool) -> None: ...
    def setModelPath(self, modelPath: Path) -> None: ...
    @overload
    def setNNArchive(self, nnArchive: depthai.NNArchive) -> None: ...
    @overload
    def setNNArchive(self, nnArchive: depthai.NNArchive, numShaves: int) -> None: ...
    def setNumInferenceThreads(self, numThreads: int) -> None: ...
    def setNumNCEPerInferenceThread(self, numNCEPerThread: int) -> None: ...
    def setNumPoolFrames(self, numFrames: int) -> None: ...
    def setNumShavesPerInferenceThread(self, numShavesPerInferenceThread: int) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def inputs(self) -> depthai.Node.InputMap: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def passthrough(self) -> depthai.Node.Output: ...
    @property
    def passthroughs(self) -> depthai.Node.OutputMap: ...

class ObjectTracker(depthai.DeviceNode):
    class Properties:
        detectionLabelsToTrack: list[int]
        maxObjectsToTrack: int
        trackerIdAssignmentPolicy: depthai.TrackerIdAssignmentPolicy
        trackerThreshold: float
        trackerType: depthai.TrackerType
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setDetectionLabelsToTrack(self, labels: list[int]) -> None: ...
    def setMaxObjectsToTrack(self, maxObjectsToTrack: int) -> None: ...
    def setTrackerIdAssignmentPolicy(self, type: depthai.TrackerIdAssignmentPolicy) -> None: ...
    def setTrackerThreshold(self, threshold: float) -> None: ...
    def setTrackerType(self, type: depthai.TrackerType) -> None: ...
    def setTrackingPerClass(self, trackingPerClass: bool) -> None: ...
    @property
    def inputDetectionFrame(self) -> depthai.Node.Input: ...
    @property
    def inputDetections(self) -> depthai.Node.Input: ...
    @property
    def inputTrackerFrame(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def passthroughDetectionFrame(self) -> depthai.Node.Output: ...
    @property
    def passthroughDetections(self) -> depthai.Node.Output: ...
    @property
    def passthroughTrackerFrame(self) -> depthai.Node.Output: ...

class PointCloud(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.PointCloudConfig
        numFramesPool: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    @property
    def initialConfig(self) -> depthai.PointCloudConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputDepth(self) -> depthai.Node.Input: ...
    @property
    def outputPointCloud(self) -> depthai.Node.Output: ...
    @property
    def passthroughDepth(self) -> depthai.Node.Output: ...

class RGBD(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def build(self) -> RGBD: ...
    @overload
    def build(self, autocreate: bool, mode: StereoDepth.PresetMode = ..., size: tuple[int,int] = ...) -> RGBD: ...
    def printDevices(self) -> None: ...
    def setDepthUnits(self, units: depthai.StereoDepthConfig.AlgorithmControl.DepthUnit) -> None: ...
    def useCPU(self) -> None: ...
    def useCPUMT(self, numThreads: int = ...) -> None: ...
    def useGPU(self, device: int = ...) -> None: ...
    @property
    def inColor(self) -> depthai.Node.Input: ...
    @property
    def inDepth(self) -> depthai.Node.Input: ...
    @property
    def pcl(self) -> depthai.Node.Output: ...
    @property
    def rgbd(self) -> depthai.Node.Output: ...

class RTABMapSLAM(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getLocalTransform(self) -> depthai.TransformData: ...
    def saveDatabase(self) -> None: ...
    def setAlphaScaling(self, alpha: float) -> None: ...
    def setDatabasePath(self, path: str) -> None: ...
    def setFreq(self, f: float) -> None: ...
    def setLoadDatabaseOnStart(self, load: bool) -> None: ...
    def setLocalTransform(self, transform: depthai.TransformData) -> None: ...
    def setParams(self, params: dict[str,str]) -> None: ...
    def setPublishGrid(self, publish: bool) -> None: ...
    def setPublishGroundCloud(self, publish: bool) -> None: ...
    def setPublishObstacleCloud(self, publish: bool) -> None: ...
    def setSaveDatabaseOnClose(self, save: bool) -> None: ...
    def setSaveDatabasePeriod(self, period: float) -> None: ...
    def setSaveDatabasePeriodically(self, save: bool) -> None: ...
    def setUseFeatures(self, useFeatures: bool) -> None: ...
    def triggerNewMap(self) -> None: ...
    @property
    def depth(self) -> depthai.Node.Input: ...
    @property
    def features(self) -> depthai.Node.Input: ...
    @property
    def groundPCL(self) -> depthai.Node.Output: ...
    @property
    def obstaclePCL(self) -> depthai.Node.Output: ...
    @property
    def occupancyGridMap(self) -> depthai.Node.Output: ...
    @property
    def odom(self) -> depthai.Node.Input: ...
    @property
    def odomCorrection(self) -> depthai.Node.Output: ...
    @property
    def passthroughDepth(self) -> depthai.Node.Output: ...
    @property
    def passthroughFeatures(self) -> depthai.Node.Output: ...
    @property
    def passthroughOdom(self) -> depthai.Node.Output: ...
    @property
    def passthroughRect(self) -> depthai.Node.Output: ...
    @property
    def rect(self) -> depthai.Node.Input: ...
    @property
    def transform(self) -> depthai.Node.Output: ...

class RTABMapVIO(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def reset(self, transform: depthai.TransformData) -> None: ...
    def setLocalTransform(self, transform: depthai.TransformData) -> None: ...
    def setParams(self, params: dict[str,str]) -> None: ...
    def setUseFeatures(self, useFeatures: bool) -> None: ...
    @property
    def depth(self) -> depthai.Node.Input: ...
    @property
    def features(self) -> depthai.Node.Input: ...
    @property
    def imu(self) -> depthai.Node.Input: ...
    @property
    def passthroughDepth(self) -> depthai.Node.Output: ...
    @property
    def passthroughFeatures(self) -> depthai.Node.Output: ...
    @property
    def passthroughRect(self) -> depthai.Node.Output: ...
    @property
    def rect(self) -> depthai.Node.Input: ...
    @property
    def transform(self) -> depthai.Node.Output: ...

class RecordMetadataOnly(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getCompressionLevel(self, *args, **kwargs) -> Any: ...
    def getRecordFile(self) -> os.PathLike: ...
    def setCompressionLevel(self, compressionLevel) -> RecordMetadataOnly: ...
    def setRecordFile(self, recordFile: os.PathLike) -> RecordMetadataOnly: ...
    @property
    def input(self) -> depthai.Node.Input: ...

class RecordVideo(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getCompressionLevel(self, *args, **kwargs) -> Any: ...
    def getRecordMetadataFile(self) -> os.PathLike: ...
    def getRecordVideoFile(self) -> os.PathLike: ...
    def setCompressionLevel(self, compressionLevel) -> RecordVideo: ...
    def setRecordMetadataFile(self, recordFile: os.PathLike) -> RecordVideo: ...
    def setRecordVideoFile(self, recordFile: os.PathLike) -> RecordVideo: ...
    @property
    def input(self) -> depthai.Node.Input: ...

class ReplayMetadataOnly(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getFps(self) -> float: ...
    def getLoop(self) -> bool: ...
    def getReplayFile(self) -> os.PathLike: ...
    def setFps(self, fps: float) -> ReplayMetadataOnly: ...
    def setLoop(self, loop: bool) -> ReplayMetadataOnly: ...
    def setReplayFile(self, replayFile: os.PathLike) -> ReplayMetadataOnly: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class ReplayVideo(ThreadedHostNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getFps(self) -> float: ...
    def getLoop(self) -> bool: ...
    def getOutFrameType(self) -> depthai.ImgFrame.Type: ...
    def getReplayMetadataFile(self) -> os.PathLike: ...
    def getReplayVideoFile(self) -> os.PathLike: ...
    def getSize(self) -> tuple[int,int]: ...
    def setFps(self, fps: float) -> ReplayVideo: ...
    def setLoop(self, loop: bool) -> ReplayVideo: ...
    def setOutFrameType(self, frameType: depthai.ImgFrame.Type) -> ReplayVideo: ...
    def setReplayMetadataFile(self, replayFile: os.PathLike) -> ReplayVideo: ...
    def setReplayVideoFile(self, replayVideoFile: os.PathLike) -> ReplayVideo: ...
    @overload
    def setSize(self, width: int, height: int) -> ReplayVideo: ...
    @overload
    def setSize(self, size: tuple[int,int]) -> ReplayVideo: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class SPIIn(depthai.DeviceNode):
    class Properties:
        busId: int
        maxDataSize: int
        numFrames: int
        streamName: str
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getBusId(self) -> int: ...
    def getMaxDataSize(self) -> int: ...
    def getNumFrames(self) -> int: ...
    def getStreamName(self) -> str: ...
    def setBusId(self, id: int) -> None: ...
    def setMaxDataSize(self, maxDataSize: int) -> None: ...
    def setNumFrames(self, numFrames: int) -> None: ...
    def setStreamName(self, name: str) -> None: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class SPIOut(depthai.DeviceNode):
    class Properties:
        busId: int
        streamName: str
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def setBusId(self, id: int) -> None: ...
    def setStreamName(self, name: str) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...

class Script(depthai.DeviceNode):
    class Properties:
        processor: depthai.ProcessorType
        scriptName: str
        scriptUri: str
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getProcessor(self) -> depthai.ProcessorType: ...
    def getScriptName(self) -> str: ...
    def setProcessor(self, arg0: depthai.ProcessorType) -> None: ...
    @overload
    def setScript(self, script: str, name: str = ...) -> None: ...
    @overload
    def setScript(self, data, std, name: str = ...) -> None: ...
    @overload
    def setScriptPath(self, arg0: Path, arg1: str) -> None: ...
    @overload
    def setScriptPath(self, path: Path, name: str = ...) -> None: ...
    @property
    def inputs(self) -> depthai.Node.InputMap: ...
    @property
    def outputs(self) -> depthai.Node.OutputMap: ...

class SpatialDetectionNetwork(depthai.DeviceNode):
    class Properties:
        depthThresholds: depthai.SpatialLocationCalculatorConfigThresholds
        detectedBBScaleFactor: float
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def build(self, input: Camera, stereo: StereoDepth, model: depthai.NNModelDescription, fps: Optional[float] = ...) -> SpatialDetectionNetwork: ...
    @overload
    def build(self, input: Camera, stereo: StereoDepth, model: str, fps: Optional[float] = ...) -> SpatialDetectionNetwork: ...
    @overload
    def build(self, input: Camera, stereo: StereoDepth, nnArchive: depthai.NNArchive, fps: Optional[float] = ...) -> SpatialDetectionNetwork: ...
    def getClasses(self) -> Optional[list[str]]: ...
    def getConfidenceThreshold(self) -> float: ...
    def getNumInferenceThreads(self) -> int: ...
    def setBackend(self, setBackend: str) -> None: ...
    def setBackendProperties(self, setBackendProperties: dict[str,str]) -> None: ...
    @overload
    def setBlob(self, blob: depthai.OpenVINO.Blob) -> None: ...
    @overload
    def setBlob(self, path: Path) -> None: ...
    def setBlobPath(self, path: Path) -> None: ...
    def setBoundingBoxScaleFactor(self, scaleFactor: float) -> None: ...
    def setConfidenceThreshold(self, thresh: float) -> None: ...
    def setDepthLowerThreshold(self, lowerThreshold: int) -> None: ...
    def setDepthUpperThreshold(self, upperThreshold: int) -> None: ...
    def setFromModelZoo(self, description: depthai.NNModelDescription, useCached: bool) -> None: ...
    def setModelPath(self, modelPath: Path) -> None: ...
    @overload
    def setNNArchive(self, archive: depthai.NNArchive) -> None: ...
    @overload
    def setNNArchive(self, archive: depthai.NNArchive, numShaves: int) -> None: ...
    def setNumInferenceThreads(self, numThreads: int) -> None: ...
    def setNumNCEPerInferenceThread(self, numNCEPerThread: int) -> None: ...
    def setNumPoolFrames(self, numFrames: int) -> None: ...
    def setNumShavesPerInferenceThread(self, numShavesPerInferenceThread: int) -> None: ...
    def setSpatialCalculationAlgorithm(self, calculationAlgorithm: depthai.SpatialLocationCalculatorAlgorithm) -> None: ...
    @property
    def boundingBoxMapping(self) -> depthai.Node.Output: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def inputDepth(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def outNetwork(self) -> depthai.Node.Output: ...
    @property
    def passthrough(self) -> depthai.Node.Output: ...
    @property
    def passthroughDepth(self) -> depthai.Node.Output: ...
    @property
    def spatialLocationCalculatorOutput(self) -> depthai.Node.Output: ...

class SpatialLocationCalculator(depthai.DeviceNode):
    class Properties:
        roiConfig: depthai.SpatialLocationCalculatorConfig
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getWaitForConfigInput(self) -> bool: ...
    def setWaitForConfigInput(self, wait: bool) -> None: ...
    @property
    def initialConfig(self) -> depthai.SpatialLocationCalculatorConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputDepth(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...
    @property
    def passthroughDepth(self) -> depthai.Node.Output: ...

class StereoDepth(depthai.DeviceNode):
    class PresetMode:
        HIGH_ACCURACY: ClassVar[StereoDepth.PresetMode] = ...  # read-only
        HIGH_DENSITY: ClassVar[StereoDepth.PresetMode] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        DEFAULT: ClassVar[StereoDepth.PresetMode] = ...
        FACE: ClassVar[StereoDepth.PresetMode] = ...
        HIGH_DETAIL: ClassVar[StereoDepth.PresetMode] = ...
        ROBOTICS: ClassVar[StereoDepth.PresetMode] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class Properties:
        class RectificationMesh:
            meshLeftUri: str
            meshRightUri: str
            meshSize: Optional[int]
            stepHeight: int
            stepWidth: int
            def __init__(self, *args, **kwargs) -> None: ...
        alphaScaling: Optional[float]
        baseline: Optional[float]
        depthAlignCamera: depthai.CameraBoardSocket
        depthAlignmentUseSpecTranslation: Optional[bool]
        disparityToDepthUseSpecTranslation: Optional[bool]
        enableRectification: bool
        enableRuntimeStereoModeSwitch: bool
        focalLength: Optional[float]
        focalLengthFromCalibration: bool
        height: Optional[int]
        initialConfig: depthai.StereoDepthConfig
        mesh: depthai.StereoDepthProperties.RectificationMesh
        numFramesPool: int
        numPostProcessingMemorySlices: int
        numPostProcessingShaves: int
        outHeight: Optional[int]
        outKeepAspectRatio: bool
        outWidth: Optional[int]
        rectificationUseSpecTranslation: Optional[bool]
        rectifyEdgeFillColor: int
        useHomographyRectification: Optional[bool]
        width: Optional[int]
        def __init__(self, *args, **kwargs) -> None: ...
    @overload
    def __init__(self, left: depthai.Node.Output, right: depthai.Node.Output, presetMode: StereoDepth.PresetMode = ...) -> None: ...
    @overload
    def __init__(self, autoCreateCameras: bool, presetMode: StereoDepth.PresetMode = ...) -> None: ...
    @overload
    def build(self, left: depthai.Node.Output, right: depthai.Node.Output, presetMode: StereoDepth.PresetMode = ...) -> StereoDepth: ...
    @overload
    def build(self, autoCreateCameras: bool, presetMode: StereoDepth.PresetMode = ..., size: tuple[int,int] = ...) -> StereoDepth: ...
    def enableDistortionCorrection(self, arg0: bool) -> None: ...
    def getMaxDisparity(self) -> float: ...
    def loadMeshData(self, *args, **kwargs) -> Any: ...
    def loadMeshFiles(self, pathLeft: Path, pathRight: Path) -> None: ...
    def setAlphaScaling(self, arg0: float) -> None: ...
    def setBaseline(self, arg0: float) -> None: ...
    def setConfidenceThreshold(self, arg0: int) -> None: ...
    def setCustomPixelDescriptors(self, arg0: bool) -> None: ...
    def setDefaultProfilePreset(self, arg0: StereoDepth.PresetMode) -> None: ...
    @overload
    def setDepthAlign(self, align: depthai.StereoDepthConfig.AlgorithmControl.DepthAlign) -> None: ...
    @overload
    def setDepthAlign(self, camera: depthai.CameraBoardSocket) -> None: ...
    def setDepthAlignmentUseSpecTranslation(self, arg0: bool) -> None: ...
    def setDisparityToDepthUseSpecTranslation(self, arg0: bool) -> None: ...
    def setEmptyCalibration(self) -> None: ...
    def setExtendedDisparity(self, enable: bool) -> None: ...
    def setFocalLength(self, arg0: float) -> None: ...
    def setFocalLengthFromCalibration(self, arg0: bool) -> None: ...
    @overload
    def setInputResolution(self, width: int, height: int) -> None: ...
    @overload
    def setInputResolution(self, resolution: tuple[int,int]) -> None: ...
    def setLeftRightCheck(self, enable: bool) -> None: ...
    def setMedianFilter(self, arg0: depthai.MedianFilter) -> None: ...
    def setMeshStep(self, width: int, height: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    def setOutputDepth(self, arg0: bool) -> None: ...
    def setOutputKeepAspectRatio(self, keep: bool) -> None: ...
    def setOutputRectified(self, arg0: bool) -> None: ...
    def setOutputSize(self, width: int, height: int) -> None: ...
    def setPostProcessingHardwareResources(self, arg0: int, arg1: int) -> None: ...
    def setRectification(self, enable: bool) -> None: ...
    def setRectificationUseSpecTranslation(self, arg0: bool) -> None: ...
    def setRectifyEdgeFillColor(self, color: int) -> None: ...
    def setRectifyMirrorFrame(self, arg0: bool) -> None: ...
    def setRuntimeModeSwitch(self, arg0: bool) -> None: ...
    def setSubpixel(self, enable: bool) -> None: ...
    def setSubpixelFractionalBits(self, subpixelFractionalBits: int) -> None: ...
    def setVerticalStereo(self, arg0: bool) -> None: ...
    def useHomographyRectification(self, arg0: bool) -> None: ...
    @property
    def confidenceMap(self) -> depthai.Node.Output: ...
    @property
    def debugDispCostDump(self) -> depthai.Node.Output: ...
    @property
    def debugDispLrCheckIt1(self) -> depthai.Node.Output: ...
    @property
    def debugDispLrCheckIt2(self) -> depthai.Node.Output: ...
    @property
    def debugExtDispLrCheckIt1(self) -> depthai.Node.Output: ...
    @property
    def debugExtDispLrCheckIt2(self) -> depthai.Node.Output: ...
    @property
    def depth(self) -> depthai.Node.Output: ...
    @property
    def disparity(self) -> depthai.Node.Output: ...
    @property
    def initialConfig(self) -> depthai.StereoDepthConfig: ...
    @property
    def inputAlignTo(self) -> depthai.Node.Input: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def inputLeftPixelDescriptor(self) -> depthai.Node.Input: ...
    @property
    def inputRightPixelDescriptor(self) -> depthai.Node.Input: ...
    @property
    def left(self) -> depthai.Node.Input: ...
    @property
    def outConfig(self) -> depthai.Node.Output: ...
    @property
    def pixelDescriptorsLeft(self) -> depthai.Node.Output: ...
    @property
    def pixelDescriptorsRight(self) -> depthai.Node.Output: ...
    @property
    def rectifiedLeft(self) -> depthai.Node.Output: ...
    @property
    def rectifiedRight(self) -> depthai.Node.Output: ...
    @property
    def right(self) -> depthai.Node.Input: ...
    @property
    def syncedLeft(self) -> depthai.Node.Output: ...
    @property
    def syncedRight(self) -> depthai.Node.Output: ...

class Sync(depthai.DeviceNode):
    class Properties:
        syncAttempts: int
        syncThresholdNs: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getSyncAttempts(self) -> int: ...
    def getSyncThreshold(self) -> datetime.timedelta: ...
    def runOnHost(self) -> bool: ...
    def setRunOnHost(self, runOnHost: bool) -> None: ...
    def setSyncAttempts(self, maxDataSize: int) -> None: ...
    def setSyncThreshold(self, syncThreshold: datetime.timedelta) -> None: ...
    @property
    def inputs(self) -> depthai.Node.InputMap: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class SystemLogger(depthai.DeviceNode):
    def __init__(self, *args, **kwargs) -> None: ...
    def getRate(self) -> float: ...
    def setRate(self, hz: float) -> None: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class Thermal(depthai.DeviceNode):
    class Properties:
        boardSocket: depthai.CameraBoardSocket
        fps: float
        initialConfig: depthai.ThermalConfig
        numFramesPool: int
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def build(self, boardSocket: depthai.CameraBoardSocket = ..., fps: float = ...) -> Thermal: ...
    def getBoardSocket(self) -> depthai.CameraBoardSocket: ...
    @property
    def color(self) -> depthai.Node.Output: ...
    @property
    def initialConfig(self) -> depthai.ThermalConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def temperature(self) -> depthai.Node.Output: ...

class ThreadedHostNode(depthai.ThreadedNode):
    createSubnode: ClassVar[function] = ...
    def __init__(self) -> None: ...
    def createInput(self, name: str = ..., group: str = ..., blocking: bool = ..., queueSize: int = ..., types: list[depthai.Node.DatatypeHierarchy] = ..., waitForMessage: bool = ...) -> depthai.Node.Input: ...
    def createOutput(self, name: str = ..., group: str = ..., possibleDatatypes: list[depthai.Node.DatatypeHierarchy] = ...) -> depthai.Node.Output: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def run(self) -> None: ...

class ToF(depthai.DeviceNode):
    class Properties:
        initialConfig: depthai.ToFConfig
        numFramesPool: int
        numShaves: int
        warpHwIds: list[int]
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def build(self, boardSocket: depthai.CameraBoardSocket = ..., fps: float = ...) -> ToF: ...
    def getBoardSocket(self) -> depthai.CameraBoardSocket: ...
    @property
    def amplitude(self) -> depthai.Node.Output: ...
    @property
    def depth(self) -> depthai.Node.Output: ...
    @property
    def initialConfig(self) -> depthai.ToFConfig: ...
    @property
    def inputConfig(self) -> depthai.Node.Input: ...
    @property
    def intensity(self) -> depthai.Node.Output: ...
    @property
    def phase(self) -> depthai.Node.Output: ...

class UVC(depthai.DeviceNode):
    class Properties:
        gpioInit: dict[int,int]
        gpioStreamOff: dict[int,int]
        gpioStreamOn: dict[int,int]
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, USBVideoClass) -> Any: ...
    def setGpiosOnInit(self, list: dict[int,int]) -> None: ...
    def setGpiosOnStreamOff(self, list: dict[int,int]) -> None: ...
    def setGpiosOnStreamOn(self, list: dict[int,int]) -> None: ...
    @property
    def input(self) -> depthai.Node.Input: ...

class VideoEncoder(depthai.DeviceNode):
    class Properties:
        class Profile:
            __members__: ClassVar[dict] = ...  # read-only
            H264_BASELINE: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            H264_HIGH: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            H264_MAIN: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            H265_MAIN: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            MJPEG: ClassVar[depthai.VideoEncoderProperties.Profile] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
    
        class RateControlMode:
            __members__: ClassVar[dict] = ...  # read-only
            CBR: ClassVar[depthai.VideoEncoderProperties.RateControlMode] = ...
            VBR: ClassVar[depthai.VideoEncoderProperties.RateControlMode] = ...
            __entries: ClassVar[dict] = ...
            def __init__(self, value: int) -> None: ...
            def __eq__(self, other: object) -> bool: ...
            def __getstate__(self) -> int: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __ne__(self, other: object) -> bool: ...
            def __setstate__(self, state: int) -> None: ...
            @property
            def name(self) -> str: ...
            @property
            def value(self) -> int: ...
        bitrate: int
        keyframeFrequency: int
        maxBitrate: int
        numBFrames: int
        numFramesPool: int
        outputFrameSize: int
        profile: depthai.VideoEncoderProperties.Profile
        quality: int
        rateCtrlMode: depthai.VideoEncoderProperties.RateControlMode
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, input: depthai.Node.Output, bitrate: float = ..., frameRate: float = ..., profile: depthai.VideoEncoderProperties.Profile = ..., keyframeFrequency: int = ..., lossless: bool = ..., quality: int = ...) -> None: ...
    def build(self, input: depthai.Node.Output, bitrate: float = ..., frameRate: float = ..., profile: depthai.VideoEncoderProperties.Profile = ..., keyframeFrequency: int = ..., lossless: bool = ..., quality: int = ...) -> VideoEncoder: ...
    def getBitrate(self) -> int: ...
    def getBitrateKbps(self) -> int: ...
    def getFrameRate(self) -> float: ...
    def getHeight(self) -> int: ...
    def getKeyframeFrequency(self) -> int: ...
    def getLossless(self) -> bool: ...
    def getMaxOutputFrameSize(self) -> int: ...
    def getNumBFrames(self) -> int: ...
    def getNumFramesPool(self) -> int: ...
    def getProfile(self) -> depthai.VideoEncoderProperties.Profile: ...
    def getQuality(self) -> int: ...
    def getRateControlMode(self) -> depthai.VideoEncoderProperties.RateControlMode: ...
    def getSize(self) -> tuple[int,int]: ...
    def getWidth(self) -> int: ...
    def setBitrate(self, bitrate: int) -> None: ...
    def setBitrateKbps(self, bitrateKbps: int) -> None: ...
    @overload
    def setDefaultProfilePreset(self, fps: float, profile: depthai.VideoEncoderProperties.Profile) -> None: ...
    @overload
    def setDefaultProfilePreset(self, arg0: int, arg1: int, arg2: float, arg3: depthai.VideoEncoderProperties.Profile) -> None: ...
    @overload
    def setDefaultProfilePreset(self, arg0: tuple[int,int], arg1: float, arg2: depthai.VideoEncoderProperties.Profile) -> None: ...
    def setFrameRate(self, frameRate: float) -> None: ...
    def setKeyframeFrequency(self, freq: int) -> None: ...
    def setLossless(self, arg0: bool) -> None: ...
    def setMaxOutputFrameSize(self, maxFrameSize: int) -> None: ...
    def setNumBFrames(self, numBFrames: int) -> None: ...
    def setNumFramesPool(self, frames: int) -> None: ...
    @overload
    def setProfile(self, profile: depthai.VideoEncoderProperties.Profile) -> None: ...
    @overload
    def setProfile(self, arg0: tuple[int,int], arg1: depthai.VideoEncoderProperties.Profile) -> None: ...
    @overload
    def setProfile(self, arg0: int, arg1: int, arg2: depthai.VideoEncoderProperties.Profile) -> None: ...
    def setQuality(self, quality: int) -> None: ...
    def setRateControlMode(self, mode: depthai.VideoEncoderProperties.RateControlMode) -> None: ...
    @property
    def bitstream(self) -> depthai.Node.Output: ...
    @property
    def input(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class Warp(depthai.DeviceNode):
    class Properties:
        def __init__(self, *args, **kwargs) -> None: ...
    def __init__(self, *args, **kwargs) -> None: ...
    def getHwIds(self) -> list[int]: ...
    def getInterpolation(self) -> depthai.Interpolation: ...
    def setHwIds(self, arg0: list[int]) -> None: ...
    def setInterpolation(self, arg0: depthai.Interpolation) -> None: ...
    def setMaxOutputFrameSize(self, arg0: int) -> None: ...
    def setNumFramesPool(self, arg0: int) -> None: ...
    @overload
    def setOutputSize(self, arg0: int, arg1: int) -> None: ...
    @overload
    def setOutputSize(self, arg0: tuple[int,int]) -> None: ...
    @overload
    def setWarpMesh(self, arg0: depthai.VectorPoint2f, arg1: int, arg2: int) -> None: ...
    @overload
    def setWarpMesh(self, arg0: list[tuple[float,float]], arg1: int, arg2: int) -> None: ...
    @property
    def inputImage(self) -> depthai.Node.Input: ...
    @property
    def out(self) -> depthai.Node.Output: ...

class YoloDetectionNetwork(DetectionNetwork):
    def __init__(self, *args, **kwargs) -> None: ...
    def getAnchorMasks(self) -> dict[str,list[int]]: ...
    def getAnchors(self) -> list[float]: ...
    def getCoordinateSize(self) -> int: ...
    def getIouThreshold(self) -> float: ...
    def getNumClasses(self) -> int: ...
    def setAnchorMasks(self, anchorMasks: dict[str,list[int]]) -> None: ...
    @overload
    def setAnchors(self, anchors: list[list[list[float]]]) -> None: ...
    @overload
    def setAnchors(self, anchors: list[float]) -> None: ...
    def setCoordinateSize(self, coordinates: int) -> None: ...
    def setIouThreshold(self, thresh: float) -> None: ...
    def setNumClasses(self, numClasses: int) -> None: ...

class YoloSpatialDetectionNetwork(SpatialDetectionNetwork):
    def __init__(self, *args, **kwargs) -> None: ...
    def getAnchorMasks(self) -> dict[str,list[int]]: ...
    def getAnchors(self) -> list[float]: ...
    def getCoordinateSize(self) -> int: ...
    def getIouThreshold(self) -> float: ...
    def getNumClasses(self) -> int: ...
    def setAnchorMasks(self, anchorMasks: dict[str,list[int]]) -> None: ...
    def setAnchors(self, anchors: list[float]) -> None: ...
    def setCoordinateSize(self, coordinates: int) -> None: ...
    def setIouThreshold(self, thresh: float) -> None: ...
    def setNumClasses(self, numClasses: int) -> None: ...
